/**
  *  \file client/tiles/baseoverview.cc
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/baseoverview.h"
#include "ui/uiglobal.h"
#include "game/planet.h"
#include "game/univ.h"
#include "util/nls.h"
#include "cpluslib/format.h"
#include "game/global.h"
#include "game/ship.h"

WBaseOverviewTile::WBaseOverviewTile(GObjectType& type)
    : WObjectTypeObserverTile(font_sizes[FONT_NORMAL].scaledBy(30, 10), type)
{ }

void
WBaseOverviewTile::drawData(GfxCanvas& can)
{
    GPlanet* p = dynamic_cast<GPlanet*>(getObject());
    if (!p)
        return;

    GPlanet& pp = *p;
    UISkin& sk = getSkin();

    sk.startDraw();

    int y = getExtent().y, x = getExtent().x;

    sk.outTextF(can, FONT_NORMAL, x, y, extent.w,
             format(_("%d mc; %d kt supplies"),
                    pp.getCargo(el_Money), pp.getCargo(el_Supplies)));
    y += font_heights[FONT_NORMAL];

    /* minerals */
    sk.outTextF(can, FONT_NORMAL, x, y, 50, _("Minerals:"));
    sk.getParameters().just_x = 2;
    sk.outTextF(can, FONT_NORMAL, x+130, y, 80, format("%dN", pp.getCargo(el_Neutronium)));
    sk.outTextF(can, FONT_NORMAL, x+210, y, 80, format("%dT", pp.getCargo(el_Tritanium)));
    sk.outTextF(can, FONT_NORMAL, x+290, y, 80, format("%dD", pp.getCargo(el_Duranium)));
    sk.outTextF(can, FONT_NORMAL, x+370, y, 80, format("%dM", pp.getCargo(el_Molybdenum)));
    y += font_heights[FONT_NORMAL];

    /* tech */
    sk.getParameters().just_x = 0;
    sk.outTextF(can, FONT_NORMAL, x, y, 100, _("Tech Levels:"));
    sk.getParameters().just_x = 2;
    sk.outTextF(can, FONT_NORMAL, x+130, y, 30, format("%dH", pp.getBaseTech(tl_Hull)));
    sk.outTextF(can, FONT_NORMAL, x+210, y, 80, format("%dE", pp.getBaseTech(tl_Engine)));
    sk.outTextF(can, FONT_NORMAL, x+290, y, 80, format("%dB", pp.getBaseTech(tl_Beam)));
    sk.outTextF(can, FONT_NORMAL, x+370, y, 80, format("%dT", pp.getBaseTech(tl_Torpedo)));
    y += font_heights[FONT_NORMAL]+2;

    /* are we building something? */
    // FIXME: use getType()'s universe
    sk.getParameters().just_x = 0;
    if (int sid = pp.getShipCloningHere(getDisplayedTurn().getCurrentUniverse())) {
        sk.outTextF(can, FONT_NORMAL, x, y, extent.w, format(_("Cloning %s"),
                                                             getDisplayedTurn().getCurrentUniverse().getShip(sid).getName()));
    } else if (int hid = pp.getBaseBuildHull()) {
        sk.outTextF(can, FONT_NORMAL, x, y, extent.w, format(_("Building a %s"), getHull(hid).getName()));
    } else {
        sk.outTextF(can, FONT_NORMAL, x, y, extent.w, string_t());
    }
    y += font_heights[FONT_NORMAL];

    /* repairing something? */
    if (pp.getBaseShipyardOrder()) {
        sk.outTextF(can, FONT_NORMAL, x, y, extent.w,
                    format(pp.getBaseShipyardOrder() == 1 ? _("Repairing %s") : _("Recycling %s"),
                           getDisplayedTurn().getCurrentUniverse().getShip(pp.getBaseShipyardId()).getFullName()));
    } else {
        sk.outTextF(can, FONT_NORMAL, x, y, extent.w, string_t());
    }
    y += font_heights[FONT_NORMAL]+2;

    /* administrivia */
    sk.outTextF(can, FONT_NORMAL, x, y, extent.w, format(_("Planetary FCode: %s"), pp.getFCode()));
    y += font_heights[FONT_NORMAL];
    sk.outTextF(can, FONT_NORMAL, x, y, extent.w,
                format(_("SB Defense: %d; Fighters: %d; Damage: %d%%"),
                       pp.getStructures(str_BaseDefense), pp.getCargo(el_Fighters), pp.getBaseDamage()));
    y += font_heights[FONT_NORMAL];

    can.update(getExtent());
}
