/**
  *  \file client/widgets/decaymsg.cc
  */

#include "client/widgets/decaymsg.h"
#include "ui/ui.h"
#include "gfx/palette.h"
#include "gfx/gfx.h"
#include "gfx/font.h"
#include "ui/uiglobal.h"

namespace {
    class WDecayingMessage : public UIFixedWidget {
        string_t text;
        int state;
     public:
        WDecayingMessage(string_t text);

        void drawContent(GfxCanvas& can);
        bool handleEvent(const UIEvent& event, bool second_pass);
    };
}

WDecayingMessage::WDecayingMessage(string_t text)
    : text(text),
      state(0)
{
    setState(st_Modal, true);
    setExtent(GfxRect(0, 0, fonts[FONT_TITLE]->getTextWidth(text) + 2, fonts[FONT_TITLE]->getTextHeight(text) + 2));
}

void
WDecayingMessage::drawContent(GfxCanvas& can)
{
    // "Frame" in COLOR_DARK
    // "Text" in COLOR_GRAYSCALE+15 .. COLOR_GRAYSCALE+7
    GfxParameters parm;
    parm.font   = fonts[FONT_TITLE];
    parm.just_x = 0;
    parm.just_y = 0;
    parm.color  = standard_colors[COLOR_DARK];

    // "Frame"
    int x = getExtent().x;
    int y = getExtent().y;
    for (int i = -1; i <= +1; ++i)
        for (int j = -1; j <= +1; ++j)
            if (i != 0 || j != 0)
                outText(can, parm, x+i, y+j, text);

    // "Text"
    if (state <= TIMER_HZ/2)
        parm.color = standard_colors[COLOR_GRAYSCALE+15];
    else
        parm.color = standard_colors[COLOR_GRAYSCALE+15 - (state - TIMER_HZ/2) * 10 / (TIMER_HZ/2)];
    outText(can, parm, x, y, text);
    can.update(getExtent());
}

bool
WDecayingMessage::handleEvent(const UIEvent& event, bool second_pass)
{
    if (event.type == ev_Tick) {
        // PCC 1.x uses a 18 Hz timer running until 16, i.e. about a second.
        // Our timer runs faster.
        ++state;
        if (state > TIMER_HZ) {
            // expired
            if (!second_pass)
                stop(0);
        } else {
            // still runs. Decay starts after half a second
            if (state > TIMER_HZ/2)
                drawWidget();
        }
        return UIFixedWidget::handleEvent(event, second_pass);
    } else if ((event.type == ev_Key
                && getClassOfKey(event.key.code & ~ss_AllMod) == KeyNormal)
               || (event.type == ev_Mouse
                   && event.mouse.b != 0))
    {
        stop(0);
        ungetEvent(event);
        return true;
    } else {
        return UIFixedWidget::handleEvent(event, second_pass);
    }
}

void
showDecayingMessage(string_t s)
{
    WDecayingMessage msg(s);
    ui_root->centerWidget(msg);
    ui_root->runModal(msg);
    ui_root->performDeferredRedraws();
}
