/**
  *  \file client/widgets/selinfo.cc
  *  \brief Selection Layer Information Widget
  */

#include "client/widgets/selinfo.h"
#include "cpluslib/format.h"
#include "game/sel.h"
#include "gfx/gfx.h"
#include "ui/skin.h"
#include "ui/uiglobal.h"
#include "ui/util.h"
#include "util/nls.h"
#include "util/strtab.h"

static const char*const formats[] = {
    N_("%d ship%!1{s%}, %d planet%!1{s%}"),
    N_("%d ship%!1{s%}"),
    N_("%d planet%!1{s%}")
};

/** Constructor.
    \param id Widget Id
    \param layer Selection layer to observe
    \pre isValidSelectionLayer(layer) */
WSelectionLayerInfo::WSelectionLayerInfo(int id, int layer)
    : UIWidget(id),
      layer(layer),
      conn_sel_change(observe(GMultiSelection::sig_selection_changed))
{ }

WSelectionLayerInfo::~WSelectionLayerInfo()
{ }

/*
   > A: 999 ships, 999 planets
 */

void
WSelectionLayerInfo::drawContent(GfxCanvas& can)
{
    UISkin& sk = getSkin();
    const GfxRect& ex = getExtent();
    const int center = ex.y + ex.h/2;

    // Draw "current" marker
    sk.drawBackground(can, GfxRect(ex.x + 4, center - 4, 4, 8));
    sk.setColor(UIColor::tc_Static);
    if (layer == GMultiSelection::getCurrentSelectionLayer()) {
        for (int i = 0; i < 4; ++i)
            drawVLine(can, sk, ex.x + 4 + i, center - 4 + i, center + 3 - i);
    }
    
    // Draw information
    string_t info = format("%c: ", 'A' + layer);
    int npl = GMultiSelection::getSelectionLayer(layer).getNumPlanets();
    int nsh = GMultiSelection::getSelectionLayer(layer).getNumShips();
    if (npl != 0) {
        if (nsh != 0)
            info += format(_(formats[0]), nsh, npl);
        else
            info += format(_(formats[2]), npl);
    } else {
        if (nsh != 0)
            info += format(_(formats[1]), nsh);
    }
    sk.outTextF(can, FONT_TITLE, ex.x + 10, center - font_heights[FONT_TITLE]/2, ex.w - 10, info);

    can.update(ex);
}

void
WSelectionLayerInfo::getLayoutInfo(LayoutInfo& info)
{
    info.pref_size = info.min_size = GfxPoint(getTextWidth(*fonts[FONT_TITLE],
                                                           StaticStringTable(formats, countof(formats))) + 10,
                                              font_heights[FONT_TITLE]);
    info.flags = li_FlexibleH;
}
