/**
  *  \file io/nullstream.h
  *  \brief Null stream (data sink)
  */
#ifndef PCC_V2_IO_NULLSTREAM_H
#define PCC_V2_IO_NULLSTREAM_H

#include "io/streams.h"

/** Null stream. This stream discards all data written to it. When
    read, it behaves like an empty file. It tracks a current position
    and size. */
class NullStream : public Stream {
    std::size_t pos, size;
 public:
    NullStream();
    ~NullStream();
    std::size_t read(char* buffer, std::size_t nbytes);
    std::size_t write(const char* buffer, std::size_t nbytes);
    int         getCapabilities() const;
    bool        seek(fpos_t pos);
    fpos_t      getSize();
    fpos_t      getPos();
    string_t    getName();
};

#endif
